@@ -397,9 +397,9 @@ pub mod comm {
         }
         let data_slice = std::slice::from_raw_parts(frame.data_ptr, frame.length as usize);
         if frame.code == RESULT_OK {
-            Ok(rmp_serde::from_read_ref(data_slice)?)
+            Ok(rmp_serde::from_slice(data_slice)?)
         } else {
-            let message: Option<String> = rmp_serde::from_read_ref(data_slice)?;
+            let message: Option<String> = rmp_serde::from_slice(data_slice)?;
             Err(EvaError::newc(frame.code.into(), message))
         }
     }
