@@ -295,27 +295,13 @@ impl Initial {
             rpc: rpc.clone(),
         }
     }
-    /// Drops current privileges to user/group if set (must be started under root)
-    ///
-    /// Note: if the service group is set to "nogroup" and the group is not found, the method
-    /// automatically tries to locate the group "nobody"
     #[inline]
     pub fn drop_privileges(&self) -> EResult<()> {
         if let Some(ref group) = self.group {
-            let g = match get_system_group(group) {
-                Ok(v) => v,
-                Err(e) if group == "nogroup" => {
-                    if let Ok(v) = get_system_group("nobody") {
-                        v
-                    } else {
-                        return Err(e);
-                    }
-                }
-                Err(e) => return Err(e),
-            };
+            let g = get_system_group(group)?;
             nix::unistd::setgroups(&[g.gid]).map_err(|e| {
                 Error::failed(format!(
-                    "Failed to switch the process group to {}: {}",
+                    "Failed to switch the process groups to {}: {}",
                     group, e
                 ))
             })?;
@@ -339,7 +325,7 @@ impl Initial {
     }
 }
 
-fn get_system_user(user: &str) -> EResult<nix::unistd::User> {
+pub fn get_system_user(user: &str) -> EResult<nix::unistd::User> {
     let u = nix::unistd::User::from_name(user)
         .map_err(|e| Error::failed(format!("failed to get the system user {}: {}", user, e)))?
         .ok_or_else(|| Error::failed(format!("Failed to locate the system user {}", user)))?;
